@@ -4,6 +4,7 @@ from .engines import mongoDocker
 from .engines import fsDefault
 from .engines import dsDefault
 from .engines import svrDefault
+from .engines import vsDefault
 # Entry Function
 
 
@@ -22,7 +23,9 @@ def start(config):
     elif (DB_ENGINE == 'dsDefault'):
         MsqModule = dsDefault
     elif (DB_ENGINE == 'svrDefault'):
-        MsqModule = svrDefault        
+        MsqModule = svrDefault
+    elif (DB_ENGINE == 'vsDefault'):
+        MsqModule = vsDefault
     else:
         MsqModule = mysqlDefault
 
